@@ -5,23 +5,23 @@ import java.util.ArrayList;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectionDialog;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectionListener;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataTypeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnTypeCodeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.LocaleTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.PeriodDataTypeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeElement;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeStore;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeElement;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeStore;
-import org.gcube.portlets.user.td.columnwidget.client.store.LocaleTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
-import org.gcube.portlets.user.td.expressionwidget.client.expression.ExpressionWrapperNotification;
-import org.gcube.portlets.user.td.expressionwidget.client.expression.ExpressionWrapperNotification.ExpressionWrapperNotificationListener;
-import org.gcube.portlets.user.td.expressionwidget.client.expression.ReplaceExpressionDialog;
+import org.gcube.portlets.user.td.expressionwidget.client.ReplaceExpressionDialog;
+import org.gcube.portlets.user.td.expressionwidget.client.notification.ExpressionWrapperNotification;
+import org.gcube.portlets.user.td.expressionwidget.client.notification.ExpressionWrapperNotification.ExpressionWrapperNotificationListener;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataTypeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnTypeCodeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.LocaleTypeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.resources.ExpressionResources;
 import org.gcube.portlets.user.td.expressionwidget.client.rpc.ExpressionServiceAsync;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeElement;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeStore;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnTypeCodeElement;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnTypeCodeStore;
+import org.gcube.portlets.user.td.expressionwidget.client.store.LocaleTypeElement;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
@@ -472,10 +472,10 @@ public class AddColumnPanel extends FramedPanel implements
 							} else {
 								defaultValueString.setValue(exWrapper
 										.getReplaceExpressionContainer()
-										.getReadableExpression());
+										.getExp().getReadableExpression());
 								defaultValueString.setToolTip(exWrapper
 										.getReplaceExpressionContainer()
-										.getReadableExpression());
+										.getExp().getReadableExpression());
 							}
 							btnAddExpression.setVisible(false);
 							btnRemoveExpression.setVisible(true);
@@ -1128,7 +1128,7 @@ public class AddColumnPanel extends FramedPanel implements
 				UtilsGXT3.alert("Attention", "Select a column type!");
 			}
 		} else {
-			UtilsGXT3.alert("Attntion", "Insert a valid label!");
+			UtilsGXT3.alert("Attention", "Insert a valid label!");
 		}
 		return columnMockUp;
 
